# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKWatershedsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkIsolatedWatershedImageFilterPython
else:
    import _itkIsolatedWatershedImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.pyBasePython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImageSourcePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython

def itkIsolatedWatershedImageFilterIF2IF2_New():
    return itkIsolatedWatershedImageFilterIF2IF2.New()

class itkIsolatedWatershedImageFilterIF2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkIsolatedWatershedImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIsolatedWatershedImageFilterIF2IF2_Pointer"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIsolatedWatershedImageFilterIF2IF2_Pointer"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_PrintSelf(self, os, indent)

    def SetSeed1(self, _arg):
        r"""
        SetSeed1(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_SetSeed1(self, _arg)

    def GetSeed1(self):
        r"""GetSeed1(self) -> itkIndex2"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_GetSeed1(self)

    def SetSeed2(self, _arg):
        r"""
        SetSeed2(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_SetSeed2(self, _arg)

    def GetSeed2(self):
        r"""GetSeed2(self) -> itkIndex2"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_GetSeed2(self)

    def SetThreshold(self, _arg):
        r"""
        SetThreshold(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_SetThreshold(self, _arg)

    def GetThreshold(self):
        r"""GetThreshold(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_GetThreshold(self)

    def SetIsolatedValueTolerance(self, _arg):
        r"""
        SetIsolatedValueTolerance(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_SetIsolatedValueTolerance(self, _arg)

    def GetIsolatedValueTolerance(self):
        r"""GetIsolatedValueTolerance(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_GetIsolatedValueTolerance(self)

    def SetUpperValueLimit(self, _arg):
        r"""
        SetUpperValueLimit(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_SetUpperValueLimit(self, _arg)

    def GetUpperValueLimit(self):
        r"""GetUpperValueLimit(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_GetUpperValueLimit(self)

    def SetReplaceValue1(self, _arg):
        r"""
        SetReplaceValue1(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_SetReplaceValue1(self, _arg)

    def GetReplaceValue1(self):
        r"""GetReplaceValue1(self) -> float"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_GetReplaceValue1(self)

    def SetReplaceValue2(self, _arg):
        r"""
        SetReplaceValue2(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_SetReplaceValue2(self, _arg)

    def GetReplaceValue2(self):
        r"""GetReplaceValue2(self) -> float"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_GetReplaceValue2(self)

    def GetIsolatedValue(self):
        r"""GetIsolatedValue(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_GetIsolatedValue(self)
    __swig_destroy__ = _itkIsolatedWatershedImageFilterPython.delete_itkIsolatedWatershedImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIsolatedWatershedImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIsolatedWatershedImageFilterIF2IF2

        Create a new object of the class itkIsolatedWatershedImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIsolatedWatershedImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIsolatedWatershedImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIsolatedWatershedImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIsolatedWatershedImageFilterIF2IF2 in _itkIsolatedWatershedImageFilterPython:
_itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF2IF2_swigregister(itkIsolatedWatershedImageFilterIF2IF2)

def itkIsolatedWatershedImageFilterIF3IF3_New():
    return itkIsolatedWatershedImageFilterIF3IF3.New()

class itkIsolatedWatershedImageFilterIF3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkIsolatedWatershedImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIsolatedWatershedImageFilterIF3IF3_Pointer"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIsolatedWatershedImageFilterIF3IF3_Pointer"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_PrintSelf(self, os, indent)

    def SetSeed1(self, _arg):
        r"""
        SetSeed1(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_SetSeed1(self, _arg)

    def GetSeed1(self):
        r"""GetSeed1(self) -> itkIndex3"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_GetSeed1(self)

    def SetSeed2(self, _arg):
        r"""
        SetSeed2(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_SetSeed2(self, _arg)

    def GetSeed2(self):
        r"""GetSeed2(self) -> itkIndex3"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_GetSeed2(self)

    def SetThreshold(self, _arg):
        r"""
        SetThreshold(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_SetThreshold(self, _arg)

    def GetThreshold(self):
        r"""GetThreshold(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_GetThreshold(self)

    def SetIsolatedValueTolerance(self, _arg):
        r"""
        SetIsolatedValueTolerance(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_SetIsolatedValueTolerance(self, _arg)

    def GetIsolatedValueTolerance(self):
        r"""GetIsolatedValueTolerance(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_GetIsolatedValueTolerance(self)

    def SetUpperValueLimit(self, _arg):
        r"""
        SetUpperValueLimit(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_SetUpperValueLimit(self, _arg)

    def GetUpperValueLimit(self):
        r"""GetUpperValueLimit(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_GetUpperValueLimit(self)

    def SetReplaceValue1(self, _arg):
        r"""
        SetReplaceValue1(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_SetReplaceValue1(self, _arg)

    def GetReplaceValue1(self):
        r"""GetReplaceValue1(self) -> float"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_GetReplaceValue1(self)

    def SetReplaceValue2(self, _arg):
        r"""
        SetReplaceValue2(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_SetReplaceValue2(self, _arg)

    def GetReplaceValue2(self):
        r"""GetReplaceValue2(self) -> float"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_GetReplaceValue2(self)

    def GetIsolatedValue(self):
        r"""GetIsolatedValue(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_GetIsolatedValue(self)
    __swig_destroy__ = _itkIsolatedWatershedImageFilterPython.delete_itkIsolatedWatershedImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIsolatedWatershedImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIsolatedWatershedImageFilterIF3IF3

        Create a new object of the class itkIsolatedWatershedImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIsolatedWatershedImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIsolatedWatershedImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIsolatedWatershedImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIsolatedWatershedImageFilterIF3IF3 in _itkIsolatedWatershedImageFilterPython:
_itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIF3IF3_swigregister(itkIsolatedWatershedImageFilterIF3IF3)

def itkIsolatedWatershedImageFilterISS2ISS2_New():
    return itkIsolatedWatershedImageFilterISS2ISS2.New()

class itkIsolatedWatershedImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkIsolatedWatershedImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIsolatedWatershedImageFilterISS2ISS2_Pointer"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIsolatedWatershedImageFilterISS2ISS2_Pointer"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_PrintSelf(self, os, indent)

    def SetSeed1(self, _arg):
        r"""
        SetSeed1(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_SetSeed1(self, _arg)

    def GetSeed1(self):
        r"""GetSeed1(self) -> itkIndex2"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_GetSeed1(self)

    def SetSeed2(self, _arg):
        r"""
        SetSeed2(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_SetSeed2(self, _arg)

    def GetSeed2(self):
        r"""GetSeed2(self) -> itkIndex2"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_GetSeed2(self)

    def SetThreshold(self, _arg):
        r"""
        SetThreshold(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_SetThreshold(self, _arg)

    def GetThreshold(self):
        r"""GetThreshold(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_GetThreshold(self)

    def SetIsolatedValueTolerance(self, _arg):
        r"""
        SetIsolatedValueTolerance(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_SetIsolatedValueTolerance(self, _arg)

    def GetIsolatedValueTolerance(self):
        r"""GetIsolatedValueTolerance(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_GetIsolatedValueTolerance(self)

    def SetUpperValueLimit(self, _arg):
        r"""
        SetUpperValueLimit(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_SetUpperValueLimit(self, _arg)

    def GetUpperValueLimit(self):
        r"""GetUpperValueLimit(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_GetUpperValueLimit(self)

    def SetReplaceValue1(self, _arg):
        r"""
        SetReplaceValue1(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_SetReplaceValue1(self, _arg)

    def GetReplaceValue1(self):
        r"""GetReplaceValue1(self) -> short"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_GetReplaceValue1(self)

    def SetReplaceValue2(self, _arg):
        r"""
        SetReplaceValue2(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_SetReplaceValue2(self, _arg)

    def GetReplaceValue2(self):
        r"""GetReplaceValue2(self) -> short"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_GetReplaceValue2(self)

    def GetIsolatedValue(self):
        r"""GetIsolatedValue(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_GetIsolatedValue(self)
    __swig_destroy__ = _itkIsolatedWatershedImageFilterPython.delete_itkIsolatedWatershedImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIsolatedWatershedImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIsolatedWatershedImageFilterISS2ISS2

        Create a new object of the class itkIsolatedWatershedImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIsolatedWatershedImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIsolatedWatershedImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIsolatedWatershedImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIsolatedWatershedImageFilterISS2ISS2 in _itkIsolatedWatershedImageFilterPython:
_itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS2ISS2_swigregister(itkIsolatedWatershedImageFilterISS2ISS2)

def itkIsolatedWatershedImageFilterISS3ISS3_New():
    return itkIsolatedWatershedImageFilterISS3ISS3.New()

class itkIsolatedWatershedImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkIsolatedWatershedImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIsolatedWatershedImageFilterISS3ISS3_Pointer"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIsolatedWatershedImageFilterISS3ISS3_Pointer"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_PrintSelf(self, os, indent)

    def SetSeed1(self, _arg):
        r"""
        SetSeed1(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_SetSeed1(self, _arg)

    def GetSeed1(self):
        r"""GetSeed1(self) -> itkIndex3"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_GetSeed1(self)

    def SetSeed2(self, _arg):
        r"""
        SetSeed2(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_SetSeed2(self, _arg)

    def GetSeed2(self):
        r"""GetSeed2(self) -> itkIndex3"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_GetSeed2(self)

    def SetThreshold(self, _arg):
        r"""
        SetThreshold(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_SetThreshold(self, _arg)

    def GetThreshold(self):
        r"""GetThreshold(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_GetThreshold(self)

    def SetIsolatedValueTolerance(self, _arg):
        r"""
        SetIsolatedValueTolerance(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_SetIsolatedValueTolerance(self, _arg)

    def GetIsolatedValueTolerance(self):
        r"""GetIsolatedValueTolerance(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_GetIsolatedValueTolerance(self)

    def SetUpperValueLimit(self, _arg):
        r"""
        SetUpperValueLimit(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_SetUpperValueLimit(self, _arg)

    def GetUpperValueLimit(self):
        r"""GetUpperValueLimit(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_GetUpperValueLimit(self)

    def SetReplaceValue1(self, _arg):
        r"""
        SetReplaceValue1(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_SetReplaceValue1(self, _arg)

    def GetReplaceValue1(self):
        r"""GetReplaceValue1(self) -> short"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_GetReplaceValue1(self)

    def SetReplaceValue2(self, _arg):
        r"""
        SetReplaceValue2(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_SetReplaceValue2(self, _arg)

    def GetReplaceValue2(self):
        r"""GetReplaceValue2(self) -> short"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_GetReplaceValue2(self)

    def GetIsolatedValue(self):
        r"""GetIsolatedValue(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_GetIsolatedValue(self)
    __swig_destroy__ = _itkIsolatedWatershedImageFilterPython.delete_itkIsolatedWatershedImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIsolatedWatershedImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIsolatedWatershedImageFilterISS3ISS3

        Create a new object of the class itkIsolatedWatershedImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIsolatedWatershedImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIsolatedWatershedImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIsolatedWatershedImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIsolatedWatershedImageFilterISS3ISS3 in _itkIsolatedWatershedImageFilterPython:
_itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterISS3ISS3_swigregister(itkIsolatedWatershedImageFilterISS3ISS3)

def itkIsolatedWatershedImageFilterIUC2IUC2_New():
    return itkIsolatedWatershedImageFilterIUC2IUC2.New()

class itkIsolatedWatershedImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkIsolatedWatershedImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIsolatedWatershedImageFilterIUC2IUC2_Pointer"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIsolatedWatershedImageFilterIUC2IUC2_Pointer"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_PrintSelf(self, os, indent)

    def SetSeed1(self, _arg):
        r"""
        SetSeed1(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_SetSeed1(self, _arg)

    def GetSeed1(self):
        r"""GetSeed1(self) -> itkIndex2"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_GetSeed1(self)

    def SetSeed2(self, _arg):
        r"""
        SetSeed2(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_SetSeed2(self, _arg)

    def GetSeed2(self):
        r"""GetSeed2(self) -> itkIndex2"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_GetSeed2(self)

    def SetThreshold(self, _arg):
        r"""
        SetThreshold(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_SetThreshold(self, _arg)

    def GetThreshold(self):
        r"""GetThreshold(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_GetThreshold(self)

    def SetIsolatedValueTolerance(self, _arg):
        r"""
        SetIsolatedValueTolerance(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_SetIsolatedValueTolerance(self, _arg)

    def GetIsolatedValueTolerance(self):
        r"""GetIsolatedValueTolerance(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_GetIsolatedValueTolerance(self)

    def SetUpperValueLimit(self, _arg):
        r"""
        SetUpperValueLimit(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_SetUpperValueLimit(self, _arg)

    def GetUpperValueLimit(self):
        r"""GetUpperValueLimit(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_GetUpperValueLimit(self)

    def SetReplaceValue1(self, _arg):
        r"""
        SetReplaceValue1(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_SetReplaceValue1(self, _arg)

    def GetReplaceValue1(self):
        r"""GetReplaceValue1(self) -> unsigned char"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_GetReplaceValue1(self)

    def SetReplaceValue2(self, _arg):
        r"""
        SetReplaceValue2(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_SetReplaceValue2(self, _arg)

    def GetReplaceValue2(self):
        r"""GetReplaceValue2(self) -> unsigned char"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_GetReplaceValue2(self)

    def GetIsolatedValue(self):
        r"""GetIsolatedValue(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_GetIsolatedValue(self)
    __swig_destroy__ = _itkIsolatedWatershedImageFilterPython.delete_itkIsolatedWatershedImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIsolatedWatershedImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIsolatedWatershedImageFilterIUC2IUC2

        Create a new object of the class itkIsolatedWatershedImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIsolatedWatershedImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIsolatedWatershedImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIsolatedWatershedImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIsolatedWatershedImageFilterIUC2IUC2 in _itkIsolatedWatershedImageFilterPython:
_itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC2IUC2_swigregister(itkIsolatedWatershedImageFilterIUC2IUC2)

def itkIsolatedWatershedImageFilterIUC3IUC3_New():
    return itkIsolatedWatershedImageFilterIUC3IUC3.New()

class itkIsolatedWatershedImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkIsolatedWatershedImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIsolatedWatershedImageFilterIUC3IUC3_Pointer"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIsolatedWatershedImageFilterIUC3IUC3_Pointer"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_PrintSelf(self, os, indent)

    def SetSeed1(self, _arg):
        r"""
        SetSeed1(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_SetSeed1(self, _arg)

    def GetSeed1(self):
        r"""GetSeed1(self) -> itkIndex3"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_GetSeed1(self)

    def SetSeed2(self, _arg):
        r"""
        SetSeed2(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_SetSeed2(self, _arg)

    def GetSeed2(self):
        r"""GetSeed2(self) -> itkIndex3"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_GetSeed2(self)

    def SetThreshold(self, _arg):
        r"""
        SetThreshold(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_SetThreshold(self, _arg)

    def GetThreshold(self):
        r"""GetThreshold(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_GetThreshold(self)

    def SetIsolatedValueTolerance(self, _arg):
        r"""
        SetIsolatedValueTolerance(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_SetIsolatedValueTolerance(self, _arg)

    def GetIsolatedValueTolerance(self):
        r"""GetIsolatedValueTolerance(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_GetIsolatedValueTolerance(self)

    def SetUpperValueLimit(self, _arg):
        r"""
        SetUpperValueLimit(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_SetUpperValueLimit(self, _arg)

    def GetUpperValueLimit(self):
        r"""GetUpperValueLimit(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_GetUpperValueLimit(self)

    def SetReplaceValue1(self, _arg):
        r"""
        SetReplaceValue1(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_SetReplaceValue1(self, _arg)

    def GetReplaceValue1(self):
        r"""GetReplaceValue1(self) -> unsigned char"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_GetReplaceValue1(self)

    def SetReplaceValue2(self, _arg):
        r"""
        SetReplaceValue2(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_SetReplaceValue2(self, _arg)

    def GetReplaceValue2(self):
        r"""GetReplaceValue2(self) -> unsigned char"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_GetReplaceValue2(self)

    def GetIsolatedValue(self):
        r"""GetIsolatedValue(self) -> double"""
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_GetIsolatedValue(self)
    __swig_destroy__ = _itkIsolatedWatershedImageFilterPython.delete_itkIsolatedWatershedImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIsolatedWatershedImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIsolatedWatershedImageFilterIUC3IUC3

        Create a new object of the class itkIsolatedWatershedImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIsolatedWatershedImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIsolatedWatershedImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIsolatedWatershedImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIsolatedWatershedImageFilterIUC3IUC3 in _itkIsolatedWatershedImageFilterPython:
_itkIsolatedWatershedImageFilterPython.itkIsolatedWatershedImageFilterIUC3IUC3_swigregister(itkIsolatedWatershedImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def isolated_watershed_image_filter(*args: itkt.ImageLike,  seed1: Sequence[int]=..., seed2: Sequence[int]=..., threshold: float=..., isolated_value_tolerance: float=..., upper_value_limit: float=..., replace_value1: int=..., replace_value2: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for IsolatedWatershedImageFilter"""
    import itk

    kwarg_typehints = { 'seed1':seed1,'seed2':seed2,'threshold':threshold,'isolated_value_tolerance':isolated_value_tolerance,'upper_value_limit':upper_value_limit,'replace_value1':replace_value1,'replace_value2':replace_value2 }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.IsolatedWatershedImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def isolated_watershed_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKWatersheds.IsolatedWatershedImageFilter
    isolated_watershed_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    isolated_watershed_image_filter.__doc__ = filter_object.__doc__



